@@ -30,10 +30,9 @@ class Calculator:
 
     def __init__(self, starting_point=None):
         # Set memory starting point.
-        if starting_point is None or self.check_type(starting_point) is False:
+        self.__starting_point = starting_point
+        if starting_point == None or self.check_type(starting_point) is False:
             self.__starting_point = 0.0
-        else:
-            self.__starting_point = starting_point
 
         self.__running_res = self.__starting_point
         self.__actions_seq = []  # type: list[__action]
@@ -80,7 +79,7 @@ class Calculator:
     def get_action_seq(self) -> str:
         """returns action sequence as a string. Example: 4 + 2 + 3 - 2 = 7"""
         string_to_print = ""
-        if self.__starting_point != 0.0:
+        if self.__starting_point != 0.0 or self.__starting_point is not None:
             string_to_print = str(self.__starting_point) + " "
 
         for current_action in self.__actions_seq:
